<template>
  <div class="bbsl-common-page">
    <div :class="['bbsl-table-search', isAdvanced ? 'advanced-search' : '']">
      <el-form v-model="queryParam" label-width="auto">
        <el-row :gutter="5">
          <el-col :span="5">
            <el-form-item label="巡逻时间" prop="walkTime">
              <el-date-picker v-model="queryParams.walkTime" clearable type="date" placeholder="请选择巡逻时间"
                value-format="yyyy-MM-dd"></el-date-picker>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="案件编号">
              <el-input clearable placeholder="请输入案件编号" v-model="queryParams.caseCode" />
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="案件来源" prop="handleStatus">
              <el-select v-model="queryParams.caseSrc" size="small" placeholder="请选择案件来源" clearable>
                <el-option v-for="item in caseSrcOpt" :key="item.value" :label="item.name" :value="item.value" />
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="案件类型" prop="caseType">
              <el-select v-model="queryParams.caseType" size="small" placeholder="请选择案件类型" clearable>
                <el-option v-for="item in caseTypeOpt" :key="item.value" :label="item.name" :value="item.value" />
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-button size="small" type="primary" icon="el-icon-search" @click="handleSearch">搜索
            </el-button>
            <el-button size="small" icon="el-icon-refresh" @click="handleReset">重置
            </el-button>
            <el-link :underline="false" type="primary" @click="advanced">
              {{ isAdvanced ? '基础搜索' : '高级搜索' }}
            </el-link>
          </el-col>
        </el-row>
        <el-row :gutter="5">
          <el-col :span="5">
            <el-form-item label="处置状态" prop="handleStatus">
              <el-select v-model="queryParams.handleStatus" size="small" placeholder="请选择处置状态" clearable>
                <el-option v-for="item in handleStatusOpt" :key="item.value" :label="item.name" :value="item.value" />
              </el-select>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div :class="['bbsl-table-content', isAdvanced ? 'advanced-search-table' : '']" ref="contentPanel">
      <el-table border size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
        :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
        :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
        @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55"></el-table-column>
        <el-table-column fixed type="index" width="55" label="序号"></el-table-column>
        <el-table-column min-width="100" fixed sortable prop="caseCode" label="案件编号"
          show-overflow-tooltip></el-table-column>
        <el-table-column fixed prop="caseReason" label="案由" show-overflow-tooltip></el-table-column>
        <el-table-column min-width="100" label="案件来源" show-overflow-tooltip
          :formatter="({ caseSrc }) => dictionaryEscape(caseSrcOpt, caseSrc)" />
        <el-table-column min-width="100" label="案件类型" show-overflow-tooltip
          :formatter="({ caseType }) => dictionaryEscape(caseTypeOpt, caseType)" />
        <el-table-column min-width="100" label="处置状态" show-overflow-tooltip
          :formatter="({ handleStatus }) => dictionaryEscape(handleStatusOpt, handleStatus)" />
        <el-table-column min-width="100" label="处置类型" show-overflow-tooltip :formatter="({ handleType }) => dictionaryEscape(handleTypeOpt, handleType, {
          congruent: false // 非全等
        })" />
        <el-table-column sortable prop="walkAddr" label="巡逻地址" show-overflow-tooltip></el-table-column>
        <el-table-column sortable prop="walkTime" label="巡逻时间" show-overflow-tooltip></el-table-column>
        <el-table-column prop="" label="操作" show-overflow-tooltip>
          <template #default="scope">
            <el-button v-if="scope.row.handleStatus == '3'" type="primary" plain size="mini"
              @click="detailBtn(scope.row)">
              详情
            </el-button>
            <el-button v-if="
              scope.row.handleStatus == '1' || scope.row.handleStatus == '2'
            " type="primary" plain size="mini" @click="auditBtn(scope.row)">
              处置
            </el-button>
          </template>
        </el-table-column>
      </el-table>
      <el-pagination align="right" background class="bbsl-pagination" ref="paginationPanel"
        @size-change="handleSizeChange" @current-change="handleCurrentChange" :current-page="queryParams.pageNum"
        :page-sizes="[20, 30, 40, 50]" :page-size="queryParams.pageSize"
        layout="total, sizes, prev, pager, next, jumper" :total="total"></el-pagination>
    </div>
    <ApprovalCaseDialog ref="formModal"></ApprovalCaseDialog>
    <ApprovalCaseDetail ref="formDetail"></ApprovalCaseDetail>
  </div>
</template>

<script>
import { TableMixin } from '@/mixins/tableMixin'
import ApprovalCaseApi from './api/ApprovalCaseApi.js'
import ApprovalCaseDialog from './components/ApprovalCaseDialog.vue'
import ApprovalCaseDetail from './components/ApprovalCaseDetail.vue'
import { dictionaryEscape } from '@/utils/dictionary'
import dictUtils from '@/components/dict/DictSelectUtils'

export default {
  name: 'CmgtSaftyPlanManage',
  components: {
    ApprovalCaseDialog,
    ApprovalCaseDetail
  },
  mixins: [TableMixin],
  data() {
    return {
      queryParams: {
        'caseCode': '',
        'caseReason': '',
        'caseSrc': '',
        'caseType': '',
        'handleStatus': '',
        'handleType': '',
        'pageNum': 1,
        'pageSize': 10,
        'walkTime': ''
      },
      caseStatusOpt: dictUtils.getDictItemsFromCache('tybagl-ajzt') || [], // 案件状态
      caseSrcOpt: dictUtils.getDictItemsFromCache('tybagl-ajl') || [], // 案件来源
      caseTypeOpt: dictUtils.getDictItemsFromCache('tybagl-ajlx') || [], // 案件类型
      handleStatusOpt: dictUtils.getDictItemsFromCache('tybagl-czzt') || [], // 处置状态
      handleTypeOpt: dictUtils.getDictItemsFromCache('tybagl-czlx') || [], // 处置类型
      total: 0,
      tableData: []
    }
  },
  created() {
  },
  methods: {
    dictionaryEscape,

    //详情
    detailBtn(row) {
      this.$refs.formDetail.Update(row)
    },

    //审核
    auditBtn(row) {
      ApprovalCaseApi.cmgtCaseSimpleHandleHandleProcess(row.id, res => {
        this.loadData()
      })
      this.$refs.formModal.Update(row)
    },

    // 重置
    clearQuerys() {
      this.queryParams = this.$options.data().queryParams
      this.queryParams.pageNum = 1
      this.loadData()
    },

    // 获取list
    loadData() {
      this.loading = true
      ApprovalCaseApi.cmgtCaseSimpleHandleListByPage(this.queryParams, res => {
        this.total = res.total
        this.tableData = res.rows
        this.loading = false
      })
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}
</style>
